==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AClassNameBaseType.h <==
// public final class soot.jimple.parser.node.AClassNameBaseType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 74decb4b70afaed3 soot_jimple_parser_node_AClassNameBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_AClassNameBaseType_H_
#define _JC_soot_jimple_parser_node_AClassNameBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PClassName$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AClassNameBaseType$sub_refs	_jc_soot_jimple_parser_node_AClassNameBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AClassNameBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_AClassNameBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AClassNameBaseType$refs	_jc_soot_jimple_parser_node_AClassNameBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_AClassNameBaseType$nonrefs	_jc_soot_jimple_parser_node_AClassNameBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AClassNameBaseType$object	_jc_soot_jimple_parser_node_AClassNameBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_AClassNameBaseType$vmethods	_jc_soot_jimple_parser_node_AClassNameBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AClassNameBaseType$vtable	_jc_soot_jimple_parser_node_AClassNameBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_AClassNameBaseType$vtype	_jc_soot_jimple_parser_node_AClassNameBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AClassNameBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *);
extern void _jc_soot_jimple_parser_node_AClassNameBaseType$method$_init$f4d6cb5b3e937cec(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *, struct _jc_soot_jimple_parser_node_PClassName$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AClassNameBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AClassNameBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *);
extern struct _jc_soot_jimple_parser_node_PClassName$object *_jc_soot_jimple_parser_node_AClassNameBaseType$method$getClassName$a22018ca45a96d40(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *);
extern void _jc_soot_jimple_parser_node_AClassNameBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AClassNameBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AClassNameBaseType$method$setClassName$594cf5bacd7331dd(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *, struct _jc_soot_jimple_parser_node_PClassName$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AClassNameBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AClassNameBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameBaseType$method_info$getClassName$a22018ca45a96d40;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameBaseType$method_info$setClassName$594cf5bacd7331dd;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AClassNameBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *);
	struct _jc_soot_jimple_parser_node_PClassName$object	*(*getClassName$a22018ca45a96d40)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setClassName$594cf5bacd7331dd)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *, struct _jc_soot_jimple_parser_node_PClassName$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AClassNameBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_AClassNameBaseType$vmethods	soot_jimple_parser_node_AClassNameBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_AClassNameBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AClassNameBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AClassNameBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_PClassName$object	*__5fclassName__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AClassNameBaseType$refs {
    _jc_soot_jimple_parser_node_AClassNameBaseType$sub_refs	soot_jimple_parser_node_AClassNameBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AClassNameBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AClassNameBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_AClassNameBaseType$sub_nonrefs	soot_jimple_parser_node_AClassNameBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AClassNameBaseType$object {
	_jc_soot_jimple_parser_node_AClassNameBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AClassNameBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_AClassNameBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AClassNameBaseType$vtype _jc_soot_jimple_parser_node_AClassNameBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AClassNameBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AClassNameBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_AClassNameBaseType_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AClassNameBaseType.h <==
// public final class soot.jimple.parser.node.AClassNameBaseType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 74decb4b70afaed3 soot_jimple_parser_node_AClassNameBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_AClassNameBaseType_H_
#define _JC_soot_jimple_parser_node_AClassNameBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PClassName$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AClassNameBaseType$sub_refs	_jc_soot_jimple_parser_node_AClassNameBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AClassNameBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_AClassNameBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AClassNameBaseType$refs	_jc_soot_jimple_parser_node_AClassNameBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_AClassNameBaseType$nonrefs	_jc_soot_jimple_parser_node_AClassNameBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AClassNameBaseType$object	_jc_soot_jimple_parser_node_AClassNameBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_AClassNameBaseType$vmethods	_jc_soot_jimple_parser_node_AClassNameBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AClassNameBaseType$vtable	_jc_soot_jimple_parser_node_AClassNameBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_AClassNameBaseType$vtype	_jc_soot_jimple_parser_node_AClassNameBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AClassNameBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AClassNameBaseType$method$_init$f4d6cb5b3e937cec(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *, struct _jc_soot_jimple_parser_node_PClassName$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AClassNameBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AClassNameBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PClassName$object *_jc_soot_jimple_parser_node_AClassNameBaseType$method$getClassName$a22018ca45a96d40(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AClassNameBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AClassNameBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AClassNameBaseType$method$setClassName$594cf5bacd7331dd(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *, struct _jc_soot_jimple_parser_node_PClassName$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AClassNameBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AClassNameBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameBaseType$method_info$getClassName$a22018ca45a96d40;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameBaseType$method_info$setClassName$594cf5bacd7331dd;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AClassNameBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PClassName$object	*(*getClassName$a22018ca45a96d40)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setClassName$594cf5bacd7331dd)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *, struct _jc_soot_jimple_parser_node_PClassName$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameBaseType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AClassNameBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_AClassNameBaseType$vmethods	soot_jimple_parser_node_AClassNameBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_AClassNameBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AClassNameBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AClassNameBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_PClassName$object	*__5fclassName__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AClassNameBaseType$refs {
    _jc_soot_jimple_parser_node_AClassNameBaseType$sub_refs	soot_jimple_parser_node_AClassNameBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AClassNameBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AClassNameBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_AClassNameBaseType$sub_nonrefs	soot_jimple_parser_node_AClassNameBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AClassNameBaseType$object {
	_jc_soot_jimple_parser_node_AClassNameBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AClassNameBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_AClassNameBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AClassNameBaseType$vtype _jc_soot_jimple_parser_node_AClassNameBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AClassNameBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AClassNameBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_AClassNameBaseType_H_ */
